==> estateplat-common-1.2.3-20180506.025257-76-sources.jar: cn/gtmap/estateplat/model/server/core/GdLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 *  过度林权
 * @author lst
 * @version V1.0, 15-5-6
 */
@Table(name = "gd_lq")
public class GdLq implements Serializable{
    @Id
    private String lqid;

    private String ldgyqk;
    private Double syqmj;
    private Date ldsyksrq;
    private Date ldsyjsrq;
    private String ldsuqxz;
    private String zysz;
    private Integer zs;
    private String lz;
    private String zlnd;
    private String xdm;
    private String lb;
    private String xb;
    private String qy;
    private String lqzl;
    private String lqzh;
    private String dw;
    private Integer iszx;
    private String djh;
    private String sjly;


    private String lmsyqr;
    private String lmsuqr;
    private String fbfmc;
    private Date gxrq;
    private String dwdm;
    private String proid;
    private String yqzh;
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxdaywh;//注销档案业务
    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getLqid() {
        return lqid;
    }

    public void setLqid(String lqid) {
        this.lqid = lqid;
    }

    public String getLdgyqk() {
        return ldgyqk;
    }

    public void setLdgyqk(String ldgyqk) {
        this.ldgyqk = ldgyqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksrq() {
        return ldsyksrq;
    }

    public void setLdsyksrq(Date ldsyksrq) {
        this.ldsyksrq = ldsyksrq;
    }

    public Date getLdsyjsrq() {
        return ldsyjsrq;
    }

    public void setLdsyjsrq(Date ldsyjsrq) {
        this.ldsyjsrq = ldsyjsrq;
    }

    public String getLdsuqxz() {
        return ldsuqxz;
    }

    public void setLdsuqxz(String ldsuqxz) {
        this.ldsuqxz = ldsuqxz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getLqzl() {
        return lqzl;
    }

    public void setLqzl(String lqzl) {
        this.lqzl = lqzl;
    }

    public String getLqzh() {
        return lqzh;
    }

    public void setLqzh(String lqzh) {
        this.lqzh = lqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }
}

==> estateplat-common-1.2.3-20190301.025841-228-sources.jar: cn/gtmap/estateplat/model/server/core/GdLq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 *  过度林权
 * @author lst
 * @version V1.0, 15-5-6
 */
@Table(name = "gd_lq")
public class GdLq implements Serializable{
    @Id
    private String lqid;

    private String ldgyqk;
    private Double syqmj;
    private Date ldsyksrq;
    private Date ldsyjsrq;
    private String ldsuqxz;
    private String zysz;
    private Integer zs;
    private String lz;
    private String zlnd;
    private String xdm;
    private String lb;
    private String xb;
    private String qy;
    private String lqzl;
    private String lqzh;
    private String dw;
    private Integer iszx;
    private String djh;
    private String sjly;
    private String lmsyqr;
    private String lmsuqr;
    private String fbfmc;
    private Date gxrq;
    private String dwdm;
    private String proid;
    private String yqzh;
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String zxdaywh;//注销档案业务
    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getLqid() {
        return lqid;
    }

    public void setLqid(String lqid) {
        this.lqid = lqid;
    }

    public String getLdgyqk() {
        return ldgyqk;
    }

    public void setLdgyqk(String ldgyqk) {
        this.ldgyqk = ldgyqk;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getLdsyksrq() {
        return ldsyksrq;
    }

    public void setLdsyksrq(Date ldsyksrq) {
        this.ldsyksrq = ldsyksrq;
    }

    public Date getLdsyjsrq() {
        return ldsyjsrq;
    }

    public void setLdsyjsrq(Date ldsyjsrq) {
        this.ldsyjsrq = ldsyjsrq;
    }

    public String getLdsuqxz() {
        return ldsuqxz;
    }

    public void setLdsuqxz(String ldsuqxz) {
        this.ldsuqxz = ldsuqxz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZlnd() {
        return zlnd;
    }

    public void setZlnd(String zlnd) {
        this.zlnd = zlnd;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getLqzl() {
        return lqzl;
    }

    public void setLqzl(String lqzl) {
        this.lqzl = lqzl;
    }

    public String getLqzh() {
        return lqzh;
    }

    public void setLqzh(String lqzh) {
        this.lqzh = lqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getLmsyqr() {
        return lmsyqr;
    }

    public void setLmsyqr(String lmsyqr) {
        this.lmsyqr = lmsyqr;
    }

    public String getLmsuqr() {
        return lmsuqr;
    }

    public void setLmsuqr(String lmsuqr) {
        this.lmsuqr = lmsuqr;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }
}
